@@ -1,8 +1,8 @@
 # Author: Oscar Perpinan Lamigueiro oscar.perpinan@gmail.es
-# Date :  June 2011
-# Version 0.10
 # Licence GPL v3
 
+
+
 ##Customization of lattice
 xscale.raster <- function(lim, ...){
   ans <- xscale.components.default(lim, ...)
@@ -27,7 +27,7 @@ yscale.raster.subticks <- function(lim, ...){
 
 xscale.raster.EW <- function(lim, ...){
   ans <- xscale.components.default(lim, ...);
-  ans$bottom$labels$labels <- parse(text=sp:::degreeLabelsEW(as.numeric(
+  ans$bottom$labels$labels <- parse(text=degreeLabelsEW(as.numeric(
                                       ans$bottom$labels$labels)))
   ans$top=FALSE  
   ans}
@@ -35,35 +35,35 @@ xscale.raster.EW <- function(lim, ...){
 xscale.raster.EWsubticks <- function(lim, ...){
   ans <- xscale.components.subticks(lim, ...)
   idx <- (ans$bottom$labels$labels!=' ')
-  ans$bottom$labels$labels[idx] <- parse(text=sp:::degreeLabelsEW(as.numeric(
+  ans$bottom$labels$labels[idx] <- parse(text=degreeLabelsEW(as.numeric(
                                            ans$bottom$labels$labels[idx])))
   ans$top=FALSE  
   ans}
 
 xscale.raster.NS <- function(lim, ...){ ## useful for hovmoller
   ans <- xscale.components.default(lim, ...);
-  ans$bottom$labels$labels <- parse(text=sp:::degreeLabelsNS(as.numeric(ans$bottom$labels$labels)))
+  ans$bottom$labels$labels <- parse(text=degreeLabelsNS(as.numeric(ans$bottom$labels$labels)))
   ans$top=FALSE  
   ans}
 
 xscale.raster.NSsubticks <- function(lim, ...){
   ans <- xscale.components.subticks(lim, ...)
   idx <- (ans$bottom$labels$labels!=' ')
-  ans$bottom$labels$labels[idx] <- parse(text=sp:::degreeLabelsNS(as.numeric(
+  ans$bottom$labels$labels[idx] <- parse(text=degreeLabelsNS(as.numeric(
                                            ans$bottom$labels$labels[idx])))
   ans$top=FALSE  
   ans}
 
 yscale.raster.NS <- function(lim, ...){
   ans <- yscale.components.default(lim, ...);
-  ans$left$labels$labels <- parse(text=sp:::degreeLabelsNS(as.numeric(ans$left$labels$labels)))
+  ans$left$labels$labels <- parse(text=degreeLabelsNS(as.numeric(ans$left$labels$labels)))
   ans$right=FALSE  
   ans}
 
 yscale.raster.NSsubticks <- function(lim, ...){
   ans <- yscale.components.subticks(lim, ...)
   idx <- (ans$left$labels$labels!=' ')
-  ans$left$labels$labels[idx] <- parse(text=sp:::degreeLabelsNS(as.numeric(
+  ans$left$labels$labels[idx] <- parse(text=degreeLabelsNS(as.numeric(
                                            ans$left$labels$labels[idx])))
   ans$right=FALSE  
   ans}
